@@ -4,23 +4,23 @@
 # on the server.
 # 
 IsValidGDELT <- function(f,
-                         local.folder) {
+                         local_folder) {
   
-  md5.url <- "http://data.gdeltproject.org/events/md5sums"
+  md5_url <- "http://data.gdeltproject.org/events/md5sums"
   
-  md5.df <- tryCatch(read.delim(md5.url, sep=" ", header=FALSE, stringsAsFactors=FALSE), 
-                     error=function(e) stop(simpleError(paste("unable to read MD5 file at", md5.url), 
+  md5_df <- tryCatch(read.delim(md5_url, sep=" ", header=FALSE, stringsAsFactors=FALSE), 
+                     error=function(e) stop(simpleError(paste("unable to read MD5 file at", md5_url), 
                                                         "IsValidGDELT")))
   
-  this.md5 <- md5.df[ md5.df[,ncol(md5.df)]==f ,1]
-  if(length(this.md5) != 1) {
+  this_md5 <- md5_df[ md5_df[,ncol(md5_df)]==f ,1]
+  if(length(this_md5) != 1) {
     warning("Unable to find MD5 for ", f)
     return(FALSE)
   }
   
-  observed.md5 <- tryCatch(md5sum(paste(StripTrailingSlashes(local.folder), "/", f, sep="")),
+  observed_md5 <- tryCatch(md5sum(paste(StripTrailingSlashes(local_folder), "/", f, sep="")),
                            error=function(e) stop(simpleError("unable to calculate MD5 for downloaded file",
                                                               "IsValidGDELT")))
   
-  return( observed.md5 == this.md5 )
+  return( observed_md5 == this_md5 )
 }
